@@ -33,6 +33,36 @@ sub		DateData {
 }
 
 
+;#=============================================================================
+;#		N A   D A T A
+;#=============================================================================
+;#		Standardized data for date (and string) testing.
+;#=============================================================================
+sub		NAData {
+		return(\$NA, \$NA, \$NA, \$NA);
+}
+
+
+;#=============================================================================
+;#		N C   D A T A
+;#=============================================================================
+;#		Standardized data for date (and string) testing.
+;#=============================================================================
+sub		NCData {
+		return(\$NC, \$NC, \$NC, \$NC);
+}
+
+
+;#=============================================================================
+;#		N D   D A T A
+;#=============================================================================
+;#		Standardized data for date (and string) testing.
+;#=============================================================================
+sub		NDData {
+		return(\$ND, \$ND, \$ND, \$ND);
+}
+
+
 ;#=============================================================================
 ;#		StartTest
 ;#=============================================================================
